ArtifactAnalysisExt extension

Extension that adds analysis convenience methods to Artifact.

on

Properties

verticalLineLeft bool

Available on Artifact, provided by the ArtifactAnalysisExt extension

Lazily evaluates and caches vertical line detection on the left side.
no setter
verticalLineRight bool

Available on Artifact, provided by the ArtifactAnalysisExt extension

Lazily evaluates and caches vertical line detection on the right side.
no setter

Methods

countVerticalStems() int

Available on Artifact, provided by the ArtifactAnalysisExt extension

Estimates the number of strong vertical stems in a glyph.
getHistogramHorizontal() List<int>

Available on Artifact, provided by the ArtifactAnalysisExt extension

Returns the horizontal histogram of the matrix.
getHistogramVertical() List<int>

Available on Artifact, provided by the ArtifactAnalysisExt extension

Returns the vertical histogram of the matrix.
hasLowerRightStroke() bool

Available on Artifact, provided by the ArtifactAnalysisExt extension

Detects ink density in the lower-right quadrant of the glyph.
hasTopHeavyHorizontalBar() bool

Available on Artifact, provided by the ArtifactAnalysisExt extension

Returns true when the glyph preserves a distinctly top-heavy bar.