countVerticalStems method
Estimates the number of strong vertical stems in a glyph.
Implementation
int countVerticalStems() => _countVerticalStems(this);
Estimates the number of strong vertical stems in a glyph.
int countVerticalStems() => _countVerticalStems(this);