hasTopHeavyHorizontalBar method
Returns true when the glyph preserves a distinctly top-heavy bar.
Implementation
bool hasTopHeavyHorizontalBar() => _hasTopHeavyHorizontalBar(this);
Returns true when the glyph preserves a distinctly top-heavy bar.
bool hasTopHeavyHorizontalBar() => _hasTopHeavyHorizontalBar(this);