removeDecorativeLineComponents method
Returns a copy with very long decorative line components removed.
Implementation
Artifact removeDecorativeLineComponents() =>
_removeDecorativeLineComponents(this);
Returns a copy with very long decorative line components removed.
Artifact removeDecorativeLineComponents() =>
_removeDecorativeLineComponents(this);