enclosures property
int
get
enclosures
Lazily evaluates and caches the number of enclosed regions.
Implementation
int get enclosures => cachedEnclosures ??= countEnclosedRegions(this);
Lazily evaluates and caches the number of enclosed regions.
int get enclosures => cachedEnclosures ??= countEnclosedRegions(this);