image_helpers library

This library is part of the Textify package. Collection of utility functions for image processing and text extraction.

Classes

IntOffset
A 2D offset with integer coordinates.
IntRect
A class representing a rectangle with integer coordinates and dimensions.

Functions

computeAdaptiveThreshold(Uint8List pixels, int width, int height) int
Computes an adaptive threshold for converting a grayscale image to black and white.
createImageFromPixels(Uint8List pixels, int width, int height) Future<Image>
Creates a new Image from a Uint8List of pixel data.
imageToBlackOnWhite(Image inputImage, {double contrast = 0}) Future<Image>
Converts a color image to a binary (black and white) image.
imageToUint8List(Image image) Future<Uint8List>
Converts a Image to a Uint8List representation.