artifact_analysis library
This library is part of the Textify package. Provides structural analysis: histograms, vertical lines, stems, and strokes.
Extensions
- ArtifactAnalysisExt on Artifact
- Extension that adds analysis convenience methods to Artifact.
Functions
-
hasVerticalLineLeft(
Artifact matrix) → bool - Checks if the artifact has a vertical line on the left side.
-
hasVerticalLineRight(
Artifact matrix) → bool - Checks if the artifact has a vertical line on the right side.