band
library
This library is part of the Textify package.
Provides Band implementation for organizing and processing Artifacts in horizontal strips.
Classes
-
Artifact
-
Represents a 2D grid of boolean values, primarily used for image processing
and pattern recognition tasks.
-
Band
-
Represents a horizontal band (aka strip) in an image/document.
Functions
-
tryJumpThreshold(List<int> gaps, int maxThreshold, {int minGapCount = Band._minArtifactsForSpaceDetection, double minJumpRatio = Band._spaceGapJumpRatio, int midpointDivisor = Band._gapMidpointDivisor})
→ int
-
Returns a threshold when sorted gaps show a clear jump in spacing.